@@ -6,7 +6,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.23
+0.24
 
 =head1 SYNOPSIS
 
@@ -117,7 +117,7 @@ use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE_
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 use constant OFFLINE => $ENV{MOJO_IRC_OFFLINE} ? 1 : 0;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -186,7 +186,7 @@ IRC username. Defaults to current logged in user or falls back to "anonymous".
 
 has ioloop => sub { Mojo::IOLoop->singleton };
 has name   => 'Mojo IRC';
-has nick   => sub { shift->user };
+has nick   => sub { shift->_build_nick };
 has parser => sub { Parse::IRC->new; };
 has pass   => '';
 has real_host => '';
@@ -551,6 +551,12 @@ sub DESTROY {
   $ioloop->remove($tid) if $tid;
 }
 
+sub _build_nick {
+  my $nick = shift->user;
+  $nick =~ s![^a-z_]!_!g;
+  $nick;
+}
+
 # Can be used in unittest to mock input data:
 # $irc->_read($bytes);
 sub _read {
